@@ -12,7 +12,7 @@ class Controller : public QObject
     Q_OBJECT
 public:
     Q_INVOKABLE static void launchApp(const QString &program);
-    Q_INVOKABLE static void runCommand(const QString &command);
+    Q_INVOKABLE static void runCommand(const QString &command, const QString &desktopFilename);
     Q_INVOKABLE bool networkAlreadyConnected();
     Q_INVOKABLE bool userFeedbackAvailable();
     Q_INVOKABLE QStringList distroPages();
