@@ -108,5 +108,10 @@ int main(int argc, char *argv[])
         }
     });
 
+    QObject::connect(&app, &QApplication::aboutToQuit, [=]() {
+        Config::self()->setLastSeenVersion(QStringLiteral(PLASMA_WELCOME_VERSION_STRING));
+        Config::self()->save();
+    });
+
     return app.exec();
 }
